<!--
    =====================================
    generator=datazen
    version=3.2.3
    hash=ee53cff1f7cb99668c93d3e8395f0078
    =====================================
-->

# experimental-lowqa ([0.1.12](https://pypi.org/project/experimental-lowqa/))

[![python](https://img.shields.io/pypi/pyversions/experimental-lowqa.svg)](https://pypi.org/project/experimental-lowqa/)
![Build Status](https://github.com/libre-embedded/experimental-lowqa/workflows/Python%20Package/badge.svg)
[![codecov](https://codecov.io/gh/libre-embedded/experimental-lowqa/branch/master/graphs/badge.svg?branch=master)](https://codecov.io/github/libre-embedded/experimental-lowqa)
![PyPI - Status](https://img.shields.io/pypi/status/experimental-lowqa)
![Dependents (via libraries.io)](https://img.shields.io/librariesio/dependents/pypi/experimental-lowqa)

*Read the sign.*

Consider [sponsoring development](https://github.com/sponsors/libre-embedded).

([interface documentation](https://libre-embedded.github.io/python/experimental-lowqa))

## Python Version Support

This package is tested with the following Python minor versions:

* [`python3.12`](https://docs.python.org/3.12/)
* [`python3.13`](https://docs.python.org/3.13/)

## Platform Support

This package is tested on the following platforms:

* `ubuntu-latest`
* `macos-latest`
* `windows-latest`

# Introduction

This project does not require 100% unit test coverage for publishing (hence
the name). **All other typical Python quality assurance is still enforced.**

# Internal Dependency Graph

A coarse view of the internal structure and scale of
`experimental-lowqa`'s source.
Generated using [pydeps](https://github.com/thebjorn/pydeps) (via
`mk python-deps`).

![experimental-lowqa's Dependency Graph](im/pydeps.svg)
